@@ -59,4 +59,4 @@ private:
     const QString mPath;
 };
 
-#endif
+#endif // STATIONDATABASE_H
